@@ -20,7 +20,6 @@
 #' bs_get_preferences()
 bs_get_preferences <- function(user = get_bluesky_user(), pass = get_bluesky_pass(),
                                auth = bs_auth(user, pass), clean = TRUE) {
-
   req <- httr2::request('https://bsky.social/xrpc/app.bsky.actor.getPreferences') |>
     httr2::req_auth_bearer_token(token = auth$accessJwt)
 
@@ -28,14 +27,18 @@ bs_get_preferences <- function(user = get_bluesky_user(), pass = get_bluesky_pas
     httr2::req_perform() |>
     httr2::resp_body_json()
 
-  if (!clean) return(resp)
+  if (!clean) {
+    return(resp)
+  }
 
   dplyr::bind_cols(
     resp$preferences[[1]] |> unlist() |> clean_names() |> tibble::as_tibble_row(),
-    resp$preferences[[2]] |>
-      lapply(unlist) |>
-      lapply(function(x) if (length(x) > 1) list(x) else x) |>
-      tibble::as_tibble() |>
-      dplyr::rename('$type2' = '$type'),
+    if (length(resp$preferences) > 1) {
+      resp$preferences[[2]] |>
+        lapply(unlist) |>
+        lapply(function(x) if (length(x) > 1) list(x) else x) |>
+        tibble::as_tibble() |>
+        dplyr::rename('$type2' = '$type')
+    }
   )
 }
