@@ -24,7 +24,6 @@
 bs_get_follows <- function(actor, cursor = NULL, limit = NULL,
                            user = get_bluesky_user(), pass = get_bluesky_pass(),
                            auth = bs_auth(user, pass), clean = TRUE) {
-
   if (missing(actor)) {
     cli::cli_abort('{.arg actor} must list one user.')
   }
@@ -52,7 +51,9 @@ bs_get_follows <- function(actor, cursor = NULL, limit = NULL,
 
   resp <- repeat_request(req, req_seq, cursor, txt = 'Fetching follows')
 
-  if (!clean) return(resp)
+  if (!clean) {
+    return(resp)
+  }
 
   resp |>
     lapply(process_follows) |>
